==> jenkins-core-1.642.3-sources.jar: hudson/views/Messages.java <==
// CHECKSTYLE:OFF

package hudson.views;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code DefaultViewsTabsBar.DisplayName}: {@code Default Views
     * TabBar}.
     * 
     * @return
     *     {@code Default Views TabBar}
     */
    public static String DefaultViewsTabsBar_DisplayName() {
        return holder.format("DefaultViewsTabsBar.DisplayName");
    }

    /**
     * Key {@code DefaultViewsTabsBar.DisplayName}: {@code Default Views
     * TabBar}.
     * 
     * @return
     *     {@code Default Views TabBar}
     */
    public static Localizable _DefaultViewsTabsBar_DisplayName() {
        return new Localizable(holder, "DefaultViewsTabsBar.DisplayName");
    }

    /**
     * Key {@code WeatherColumn.DisplayName}: {@code Weather}.
     * 
     * @return
     *     {@code Weather}
     */
    public static String WeatherColumn_DisplayName() {
        return holder.format("WeatherColumn.DisplayName");
    }

    /**
     * Key {@code WeatherColumn.DisplayName}: {@code Weather}.
     * 
     * @return
     *     {@code Weather}
     */
    public static Localizable _WeatherColumn_DisplayName() {
        return new Localizable(holder, "WeatherColumn.DisplayName");
    }

    /**
     * Key {@code StatusColumn.DisplayName}: {@code Status}.
     * 
     * @return
     *     {@code Status}
     */
    public static String StatusColumn_DisplayName() {
        return holder.format("StatusColumn.DisplayName");
    }

    /**
     * Key {@code StatusColumn.DisplayName}: {@code Status}.
     * 
     * @return
     *     {@code Status}
     */
    public static Localizable _StatusColumn_DisplayName() {
        return new Localizable(holder, "StatusColumn.DisplayName");
    }

    /**
     * Key {@code LastFailureColumn.DisplayName}: {@code Last Failure}.
     * 
     * @return
     *     {@code Last Failure}
     */
    public static String LastFailureColumn_DisplayName() {
        return holder.format("LastFailureColumn.DisplayName");
    }

    /**
     * Key {@code LastFailureColumn.DisplayName}: {@code Last Failure}.
     * 
     * @return
     *     {@code Last Failure}
     */
    public static Localizable _LastFailureColumn_DisplayName() {
        return new Localizable(holder, "LastFailureColumn.DisplayName");
    }

    /**
     * Key {@code DefaultMyViewsTabsBar.DisplayName}: {@code Default My Views
     * TabBar}.
     * 
     * @return
     *     {@code Default My Views TabBar}
     */
    public static String DefaultMyViewsTabsBar_DisplayName() {
        return holder.format("DefaultMyViewsTabsBar.DisplayName");
    }

    /**
     * Key {@code DefaultMyViewsTabsBar.DisplayName}: {@code Default My Views
     * TabBar}.
     * 
     * @return
     *     {@code Default My Views TabBar}
     */
    public static Localizable _DefaultMyViewsTabsBar_DisplayName() {
        return new Localizable(holder, "DefaultMyViewsTabsBar.DisplayName");
    }

    /**
     * Key {@code LastDurationColumn.DisplayName}: {@code Last Duration}.
     * 
     * @return
     *     {@code Last Duration}
     */
    public static String LastDurationColumn_DisplayName() {
        return holder.format("LastDurationColumn.DisplayName");
    }

    /**
     * Key {@code LastDurationColumn.DisplayName}: {@code Last Duration}.
     * 
     * @return
     *     {@code Last Duration}
     */
    public static Localizable _LastDurationColumn_DisplayName() {
        return new Localizable(holder, "LastDurationColumn.DisplayName");
    }

    /**
     * Key {@code JobColumn.DisplayName}: {@code Name}.
     * 
     * @return
     *     {@code Name}
     */
    public static String JobColumn_DisplayName() {
        return holder.format("JobColumn.DisplayName");
    }

    /**
     * Key {@code JobColumn.DisplayName}: {@code Name}.
     * 
     * @return
     *     {@code Name}
     */
    public static Localizable _JobColumn_DisplayName() {
        return new Localizable(holder, "JobColumn.DisplayName");
    }

    /**
     * Key {@code BuildButtonColumn.DisplayName}: {@code Build Button}.
     * 
     * @return
     *     {@code Build Button}
     */
    public static String BuildButtonColumn_DisplayName() {
        return holder.format("BuildButtonColumn.DisplayName");
    }

    /**
     * Key {@code BuildButtonColumn.DisplayName}: {@code Build Button}.
     * 
     * @return
     *     {@code Build Button}
     */
    public static Localizable _BuildButtonColumn_DisplayName() {
        return new Localizable(holder, "BuildButtonColumn.DisplayName");
    }

    /**
     * Key {@code LastSuccessColumn.DisplayName}: {@code Last Success}.
     * 
     * @return
     *     {@code Last Success}
     */
    public static String LastSuccessColumn_DisplayName() {
        return holder.format("LastSuccessColumn.DisplayName");
    }

    /**
     * Key {@code LastSuccessColumn.DisplayName}: {@code Last Success}.
     * 
     * @return
     *     {@code Last Success}
     */
    public static Localizable _LastSuccessColumn_DisplayName() {
        return new Localizable(holder, "LastSuccessColumn.DisplayName");
    }

    /**
     * Key {@code LastStableColumn.DisplayName}: {@code Last Stable}.
     * 
     * @return
     *     {@code Last Stable}
     */
    public static String LastStableColumn_DisplayName() {
        return holder.format("LastStableColumn.DisplayName");
    }

    /**
     * Key {@code LastStableColumn.DisplayName}: {@code Last Stable}.
     * 
     * @return
     *     {@code Last Stable}
     */
    public static Localizable _LastStableColumn_DisplayName() {
        return new Localizable(holder, "LastStableColumn.DisplayName");
    }

}

==> jenkins-core-2.414.1-sources.jar: hudson/views/Messages.java <==
// CHECKSTYLE:OFF

package hudson.views;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code WeatherColumn.DisplayName}: {@code Weather}.
     * 
     * @return
     *     {@code Weather}
     */
    public static String WeatherColumn_DisplayName() {
        return holder.format("WeatherColumn.DisplayName");
    }

    /**
     * Key {@code WeatherColumn.DisplayName}: {@code Weather}.
     * 
     * @return
     *     {@code Weather}
     */
    public static Localizable _WeatherColumn_DisplayName() {
        return new Localizable(holder, "WeatherColumn.DisplayName");
    }

    /**
     * Key {@code LastSuccessColumn.DisplayName}: {@code Last Success}.
     * 
     * @return
     *     {@code Last Success}
     */
    public static String LastSuccessColumn_DisplayName() {
        return holder.format("LastSuccessColumn.DisplayName");
    }

    /**
     * Key {@code LastSuccessColumn.DisplayName}: {@code Last Success}.
     * 
     * @return
     *     {@code Last Success}
     */
    public static Localizable _LastSuccessColumn_DisplayName() {
        return new Localizable(holder, "LastSuccessColumn.DisplayName");
    }

    /**
     * Key {@code JobColumn.DisplayName}: {@code Name}.
     * 
     * @return
     *     {@code Name}
     */
    public static String JobColumn_DisplayName() {
        return holder.format("JobColumn.DisplayName");
    }

    /**
     * Key {@code JobColumn.DisplayName}: {@code Name}.
     * 
     * @return
     *     {@code Name}
     */
    public static Localizable _JobColumn_DisplayName() {
        return new Localizable(holder, "JobColumn.DisplayName");
    }

    /**
     * Key {@code LastDurationColumn.DisplayName}: {@code Last Duration}.
     * 
     * @return
     *     {@code Last Duration}
     */
    public static String LastDurationColumn_DisplayName() {
        return holder.format("LastDurationColumn.DisplayName");
    }

    /**
     * Key {@code LastDurationColumn.DisplayName}: {@code Last Duration}.
     * 
     * @return
     *     {@code Last Duration}
     */
    public static Localizable _LastDurationColumn_DisplayName() {
        return new Localizable(holder, "LastDurationColumn.DisplayName");
    }

    /**
     * Key {@code DefaultMyViewsTabsBar.DisplayName}: {@code Default My Views
     * TabBar}.
     * 
     * @return
     *     {@code Default My Views TabBar}
     */
    public static String DefaultMyViewsTabsBar_DisplayName() {
        return holder.format("DefaultMyViewsTabsBar.DisplayName");
    }

    /**
     * Key {@code DefaultMyViewsTabsBar.DisplayName}: {@code Default My Views
     * TabBar}.
     * 
     * @return
     *     {@code Default My Views TabBar}
     */
    public static Localizable _DefaultMyViewsTabsBar_DisplayName() {
        return new Localizable(holder, "DefaultMyViewsTabsBar.DisplayName");
    }

    /**
     * Key {@code GlobalDefaultViewConfiguration.ViewDoesNotExist}: {@code
     * The specified view does not exist: {0}}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code The specified view does not exist: {0}}
     */
    public static String GlobalDefaultViewConfiguration_ViewDoesNotExist(Object arg0) {
        return holder.format("GlobalDefaultViewConfiguration.ViewDoesNotExist", arg0);
    }

    /**
     * Key {@code GlobalDefaultViewConfiguration.ViewDoesNotExist}: {@code
     * The specified view does not exist: {0}}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code The specified view does not exist: {0}}
     */
    public static Localizable _GlobalDefaultViewConfiguration_ViewDoesNotExist(Object arg0) {
        return new Localizable(holder, "GlobalDefaultViewConfiguration.ViewDoesNotExist", arg0);
    }

    /**
     * Key {@code BuildButtonColumn.DisplayName}: {@code Build Button}.
     * 
     * @return
     *     {@code Build Button}
     */
    public static String BuildButtonColumn_DisplayName() {
        return holder.format("BuildButtonColumn.DisplayName");
    }

    /**
     * Key {@code BuildButtonColumn.DisplayName}: {@code Build Button}.
     * 
     * @return
     *     {@code Build Button}
     */
    public static Localizable _BuildButtonColumn_DisplayName() {
        return new Localizable(holder, "BuildButtonColumn.DisplayName");
    }

    /**
     * Key {@code LastStableColumn.DisplayName}: {@code Last Stable}.
     * 
     * @return
     *     {@code Last Stable}
     */
    public static String LastStableColumn_DisplayName() {
        return holder.format("LastStableColumn.DisplayName");
    }

    /**
     * Key {@code LastStableColumn.DisplayName}: {@code Last Stable}.
     * 
     * @return
     *     {@code Last Stable}
     */
    public static Localizable _LastStableColumn_DisplayName() {
        return new Localizable(holder, "LastStableColumn.DisplayName");
    }

    /**
     * Key {@code DefaultViewsTabsBar.DisplayName}: {@code Default Views
     * TabBar}.
     * 
     * @return
     *     {@code Default Views TabBar}
     */
    public static String DefaultViewsTabsBar_DisplayName() {
        return holder.format("DefaultViewsTabsBar.DisplayName");
    }

    /**
     * Key {@code DefaultViewsTabsBar.DisplayName}: {@code Default Views
     * TabBar}.
     * 
     * @return
     *     {@code Default Views TabBar}
     */
    public static Localizable _DefaultViewsTabsBar_DisplayName() {
        return new Localizable(holder, "DefaultViewsTabsBar.DisplayName");
    }

    /**
     * Key {@code LastFailureColumn.DisplayName}: {@code Last Failure}.
     * 
     * @return
     *     {@code Last Failure}
     */
    public static String LastFailureColumn_DisplayName() {
        return holder.format("LastFailureColumn.DisplayName");
    }

    /**
     * Key {@code LastFailureColumn.DisplayName}: {@code Last Failure}.
     * 
     * @return
     *     {@code Last Failure}
     */
    public static Localizable _LastFailureColumn_DisplayName() {
        return new Localizable(holder, "LastFailureColumn.DisplayName");
    }

    /**
     * Key {@code StatusColumn.DisplayName}: {@code Status}.
     * 
     * @return
     *     {@code Status}
     */
    public static String StatusColumn_DisplayName() {
        return holder.format("StatusColumn.DisplayName");
    }

    /**
     * Key {@code StatusColumn.DisplayName}: {@code Status}.
     * 
     * @return
     *     {@code Status}
     */
    public static Localizable _StatusColumn_DisplayName() {
        return new Localizable(holder, "StatusColumn.DisplayName");
    }

    /**
     * Key {@code StatusFilter.DisplayName}: {@code Status Filter}.
     * 
     * @return
     *     {@code Status Filter}
     */
    public static String StatusFilter_DisplayName() {
        return holder.format("StatusFilter.DisplayName");
    }

    /**
     * Key {@code StatusFilter.DisplayName}: {@code Status Filter}.
     * 
     * @return
     *     {@code Status Filter}
     */
    public static Localizable _StatusFilter_DisplayName() {
        return new Localizable(holder, "StatusFilter.DisplayName");
    }

}
